<?php
/**
 * Custom recent post widget.
 *
 * @package fad
 * @since 1.0.0
 */

/**
 * Defines the custom widget class.
 */
if ( ! class_exists( 'Fad_Recent_Posts_Widget' ) ) {
	/**
	 * Defines the custom widget class.
	 *
	 * @extends WP_Widget
	 */
	class Fad_Recent_Posts_Widget extends WP_Widget {
		/**
		 * Class constructor.
		 */
		public function __construct() {
			$widget_options = array(
				'classname'   => 'fad_recent_posts_widget',
				'description' => __( 'Display list of recent posts along with their featured images.', 'fad' ),
			);

			parent::__construct( 'fad_recent_posts_widget', __( 'Fad Recent Posts', 'fad' ), $widget_options );
		}

		/**
		 * Outputs the widget markup.
		 *
		 * @param  string $args     argument options.
		 * @param  string $instance The values of the current widget.
		 */
		public function widget( $args, $instance ) {
			// before and after widget arguments are defined by themes.
			$allowed_html_tags = array(
				'section' => array(
					'id'    => array(),
					'class' => array(),
				),
				'div'     => array(
					'id'    => array(),
					'class' => array(),
				),
				'h2'      => array(
					'id'    => array(),
					'class' => array(),
				),
				'h3'      => array(
					'id'    => array(),
					'class' => array(),
				),
				'h4'      => array(
					'id'    => array(),
					'class' => array(),
				),
			);

			echo wp_kses( $args['before_widget'], $allowed_html_tags );

			if ( ! isset( $args['widget_id'] ) ) {
				$args['widget_id'] = $this->id;
			}

			$fad_recent_posts_widget_number = ( ! empty( $instance['fad_recent_posts_widget_number'] ) ) ? absint( $instance['fad_recent_posts_widget_number'] ) : 3;
			if ( ! $fad_recent_posts_widget_number ) {
				$fad_recent_posts_widget_number = 3;
			}

			$fad_recent_posts_widget_query = new WP_Query(
				apply_filters(
					'widget_posts_args',
					array(
						'posts_per_page'      => $fad_recent_posts_widget_number,
						'no_found_rows'       => true,
						'post_status'         => 'publish',
						'ignore_sticky_posts' => true,
					)
				)
			);

			if ( $fad_recent_posts_widget_query->have_posts() ) :

				if ( ! empty( $instance['fad_recent_posts_widget_title'] ) ) {
					echo wp_kses( $args['before_title'], $allowed_html_tags ) .
					esc_html( $instance['fad_recent_posts_widget_title'] ) .
					wp_kses( $args['after_title'], $allowed_html_tags );
				}
				?>
				<ul>
					<?php
					while ( $fad_recent_posts_widget_query->have_posts() ) :
						$fad_recent_posts_widget_query->the_post();

						?>
						<li>
							<div class="row">
								<?php
								if ( has_post_thumbnail() ) {
									$fad_recent_post_widget_class = "col-xs-8 col-sm-8 col-md-8";
								?>
									<div class="col-xs-4 col-sm-4 col-md-4">								
										<?php the_post_thumbnail( array( 150, 150 ) ); ?>								
									</div>
								<?php
								}
								else
								{
									$fad_recent_post_widget_class = "col-xs-12 col-sm-12 col-md-12";
								}
								?>
								<div class="<?php echo esc_attr( $fad_recent_post_widget_class ); ?>">
									<a class="fad_recent_post_widget_title" href="<?php the_permalink(); ?>" title="<?php echo esc_attr( get_the_title() ? get_the_title() : get_the_ID() ); ?>">
										<?php
										if ( get_the_title() ) {
											the_title();
										} else {
											the_ID();
										}
										?>
									</a>
									<?php
									$date = get_the_date( 'j M Y' );
									echo '<a class="fad_recent_posts_widget_date" href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . esc_html( $date ) . '</a>';
									?>
								</div>
							</div>
						</li>
						<?php

					endwhile;
					?>

				</ul>
				<?php

			endif;

			echo wp_kses( $args['after_widget'], $allowed_html_tags );
		}

		/**
		 * Displays the widget form in the admin dashboard.
		 *
		 * @param  string $instance The current values of the widget.
		 */
		public function form( $instance ) {
			$instance = wp_parse_args(
				(array) $instance,
				array(
					'fad_recent_posts_widget_title'  => '',
					'fad_recent_posts_widget_number' => '3',
				)
			);

			// Widget admin form.
			?>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'fad_recent_posts_widget_title' ) ); ?>"><?php esc_html_e( 'Title:', 'fad' ); ?></label>
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'fad_recent_posts_widget_title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'fad_recent_posts_widget_title' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['fad_recent_posts_widget_title'] ); ?>" />
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'fad_recent_posts_widget_number' ) ); ?>"><?php esc_html_e( 'Number of posts to show:', 'fad' ); ?></label>
				<input id="<?php echo esc_attr( $this->get_field_id( 'fad_recent_posts_widget_number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'fad_recent_posts_widget_number' ) ); ?>" type="text" value="<?php echo esc_attr( $instance['fad_recent_posts_widget_number'] ); ?>" size="3" />
			</p>
			<?php
		}

		/**
		 * Updates the widget.
		 *
		 * @param  string $new_instance The new values of submitted widget.
		 * @param  string $old_instance The old values of the submitted widget.
		 */
		public function update( $new_instance, $old_instance ) {
			return array(
				'fad_recent_posts_widget_title'  => esc_html( $new_instance['fad_recent_posts_widget_title'] ),
				'fad_recent_posts_widget_number' => (int) ( $new_instance['fad_recent_posts_widget_number'] ),
			);
		}
	} // Class fad_recent_posts_widget ends here
} // If ends.

/**
 * Registers the recent posts widget.
 */
if ( ! function_exists( 'fad_recent_posts_widget_register' ) ) {
	/**
	 * Registers the recent posts widget.
	 *
	 * @return void
	 */
	function fad_recent_posts_widget_register() {
		register_widget( 'Fad_Recent_Posts_Widget' );
	}

	add_action( 'widgets_init', 'fad_recent_posts_widget_register' );
}
